@@ -38,16 +38,19 @@ class Base:
 
 @dataclass
 class Type(Base):
-    """Type class represents type for other classes."""
+    """Type class represents type for [Item](), [Section](), [Docstring](),
+    and [Object]()."""
 
     def __post_init__(self):
         if not self.markdown:
             self.markdown = self.name
 
-    def __bool__(self):
+    def __bool__(self) -> bool:
+        """Returns True if name is not empty."""
         return self.name != ""
 
     def __iter__(self) -> Iterator[Base]:
+        """Yields self if the markdown attribute has link form."""
         if LINK_PATTERN.search(self.markdown):
             yield self
 
@@ -58,7 +61,14 @@ class Type(Base):
 
 @dataclass
 class Item(Base):
-    """Item class represents an item in Parameters, Attributes, and Raises sections."""
+    """Item class represents an item in Parameters, Attributes, and Raises sections.
+
+    Args:
+        type: Type of item.
+
+    Attributes:
+        type: Type of item.
+    """
 
     type: Type = field(default_factory=Type)
 
@@ -77,9 +87,11 @@ class Section(Base):
 
     Args:
         items: List for Arguments, Attributes, or Raises sections.
+        type: Type of item.
 
     Attributes:
         items: List for Arguments, Attributes, or Raises sections.
+        type: Type of item.
 
     Examples:
         `Section` is iterable:
@@ -111,6 +123,11 @@ class Section(Base):
             self.markdown = mkapi.core.preprocess.convert(self.markdown)
 
     def __iter__(self) -> Iterator[Base]:
+        """Yields [Base]() instance that has non empty Markdown.
+
+        Args:
+            name: Item name.
+        """
         yield from self.type
         if self.markdown:
             yield self
@@ -118,12 +135,23 @@ class Section(Base):
             yield from item
 
     def __getitem__(self, name) -> Optional[Item]:
+        """Returns [Item]() instance whose name is equal to `name`. If not found,
+        returns None.
+
+        Args:
+            name: Item name.
+        """
         for item in self.items:
             if item.name == name:
                 return item
         return None
 
     def __contains__(self, name) -> bool:
+        """Returns True if there is [Item]() instance whose name is `name`.
+
+        Args:
+            name: Item name.
+        """
         return self[name] is not None
 
 
@@ -137,7 +165,7 @@ class Docstring:
 
     Attributes:
         sections: List of Section instance.
-        type: Type for Returns and Yields sections.
+        type: Type for missing Returns and Yields sections.
 
     Examples:
         Empty docstring:
@@ -192,7 +220,18 @@ class Docstring:
 
 @dataclass
 class Object(Base):
-    """Object class represents an object."""
+    """Object class represents an object.
+
+    Args:
+        name: Object name. `Item` for `Item` class.
+        prefix: Object prefix. `mkapi.core.base` for `Item` class.
+        kind: Object kind such as 'class', 'function'. etc.
+        type: Type for missing Returns and Yields sections.
+        signature: Signature if object is callable.
+
+    Attributes:
+        id: CSS ID.
+    """
 
     prefix: str = ""
     id: str = field(init=False)
